# ZLE (Symbolic Integer-Linear Matrix Toolkit)

[![PyPI - Version](https://img.shields.io/pypi/v/zlepy)](https://pypi.org/project/zlepy)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zlepy)](https://pypi.org/project/zlepy)

-----

A Python package to aid in integer-linear eigenvalue matrix generation and symbolic evaluation. Part of the [symeig](https://github.com/symeig) project.

## Table of Contents

- [Installation](#installation)
- [Testing](#testing)
- [License](#license)

## Installation
From PyPI
```console
pip install zlepy
```

For local development:
```console
pip install -e path/to/zlepy
```

## Testing

All tests:
```
hatch test
```

Specific test file:
```
hatch test tests/test_batch_sizes.py
```

## License

This package is OSI approved under the Apache License Version 2.0.
